Module change_tracker

Module change_tracker 

Change tracking and dirty detection for SQLModel Session.

This module provides snapshot-based change tracking to detect when objects have been modified since they were loaded from the database.

Structs

ChangeTracker
Tracks changes to objects in the session.
ObjectSnapshot
Snapshot of an object’s state at a point in time.