pub type ModelReadGuard<'a, M> = RwLockReadGuard<'a, M>;Expand description
A guard for reading an object from the identity map.
Aliased Type
pub struct ModelReadGuard<'a, M> { /* private fields */ }pub type ModelReadGuard<'a, M> = RwLockReadGuard<'a, M>;A guard for reading an object from the identity map.
pub struct ModelReadGuard<'a, M> { /* private fields */ }