pub type ModelWriteGuard<'a, M> = RwLockWriteGuard<'a, M>;Expand description
A guard for writing to an object in the identity map.
Aliased Type
pub struct ModelWriteGuard<'a, M> { /* private fields */ }pub type ModelWriteGuard<'a, M> = RwLockWriteGuard<'a, M>;A guard for writing to an object in the identity map.
pub struct ModelWriteGuard<'a, M> { /* private fields */ }