pub enum PendingOp {
Insert {
key: ObjectKey,
table: &'static str,
columns: Vec<&'static str>,
values: Vec<Value>,
},
Update {
key: ObjectKey,
table: &'static str,
pk_columns: Vec<&'static str>,
pk_values: Vec<Value>,
set_columns: Vec<&'static str>,
set_values: Vec<Value>,
},
Delete {
key: ObjectKey,
table: &'static str,
pk_columns: Vec<&'static str>,
pk_values: Vec<Value>,
},
}Expand description
A pending database operation.
Variants
Implementations
Sourceimpl PendingOp
impl PendingOp
Sourcepub fn to_sql(&self) -> String
pub fn to_sql(&self) -> String
Generate the SQL that would be executed for this operation.
This is useful for testing and debugging. For INSERT, this generates a single-row insert. For DELETE/UPDATE, the SQL matches what would be executed for a single operation.
Returns a descriptive error string for invalid operations (e.g., empty pk_columns for DELETE/UPDATE, empty set_columns for UPDATE).