pub struct FlushOrderer { /* private fields */ }Expand description
Builds a dependency graph and orders operations for flush.
Uses table foreign key relationships to determine correct ordering:
- Parents must be inserted before children
- Children must be deleted before parents
Implementations
Sourceimpl FlushOrderer
impl FlushOrderer
Sourcepub fn register_model<T: Model>(&mut self)
pub fn register_model<T: Model>(&mut self)
Register a model type’s dependencies.
Extracts foreign key relationships from the model’s field metadata.
Sourcepub fn register_table(
&mut self,
table: &'static str,
depends_on: Vec<&'static str>,
)
pub fn register_table( &mut self, table: &'static str, depends_on: Vec<&'static str>, )
Register a table’s dependencies directly.